@@ -1,5 +1,4 @@
-from formatter2 import TokenOffsets, TokenOffset, TOKEN_OFFSETS
-from formatter2 import tokens
+from formatter2 import TokenOffsets, TokenOffset, TOKEN_OFFSETS, tokens
 import nose
 from StringIO import StringIO
 import logging
